@@ -224,8 +224,6 @@ def evaluate_task_outbound_context(task_ex):
         if task_ex.in_context is not None else {}
     )
 
-    remove_current_task_from_context(in_context)
-
     return utils.update_dict(in_context, task_ex.published)
 
 
@@ -256,7 +254,7 @@ def add_current_task_to_context(ctx, task_id, task_name):
     return ctx
 
 
-def remove_current_task_from_context(ctx):
+def remove_internal_data_from_context(ctx):
     if '__task_execution' in ctx:
         del ctx['__task_execution']
 
